- Add a new `BSplineBasis` class that does not hold trainable coefficients, but only the knot vector in a buffer, to allow using coefficients that come from another model
- The `BSplineCurve` class now uses `BSplineBasis` internally. 
